==> fonts-sil-lateef_2.000.orig.tar.xz: Lateef-2.000/documentation/source/index.md <==
---
title: Lateef - Documentation
fontversion: 2.000
---

Thank you for your interest in the Lateef font. Lateef includes near-complete support for Unicode 13.0 Arabic ranges (excluding the Arabic Presentation Forms blocks, which are not recommended for normal use).

This documentation is a set of HTML pages that can be viewed in any modern web browser. PDF versions of these pages are also provided. This content, plus download links and a contact form, are available from the [Lateef site](https://software.sil.org/lateef/).

- [About](about.md) &mdash; Information about this project and SIL International
- [Resources](resources.md) &mdash; Help with installation and use
- [FAQ](faq.md) &mdash; Common questions and answers
- [Design](design.md) &mdash; History and background of the design
- [Character set support](charset.md) &mdash; Details of Unicode characters that are supported
- [Type Sample](sample.md) &mdash; Type sample demonstrating all the characters in this font
- [Font features](features.md) &mdash; Using smart font features
- [Rendering the Allah ligature](allah.md) &mdash; Special rules for rendering the Allah ligature
- [Support](support.md) &mdash; How to get additional support
- [Developer information](developer.md) &mdash; How to modify and build the fonts
- [Versions](versions.md) &mdash; Sources for alternate versions
- [Version history](history.md) &mdash; Complete version history
- [Announcement](announcement.md) &mdash; Source for News announcement

Additional information is also provided in other project files: [README.txt](../README.txt), [OFL.txt](../OFL.txt), [OFL-FAQ.txt](../OFL-FAQ.txt), and [FONTLOG.txt](../FONTLOG.txt).

==> fonts-sil-lateef_4.200.orig.tar.xz: Lateef-4.200/documentation/source/index.md <==
---
title: Lateef - Documentation
fontversion: 4.200
---

Thank you for your interest in the Lateef font. Lateef includes full support for Unicode 15.0 Arabic ranges (excluding the Arabic Presentation Forms blocks, which are not recommended for normal use).

This documentation is a set of HTML pages that can be viewed in any modern web browser. PDF versions of these pages are also provided. This content, plus download links and a contact form, are available from the [Lateef site](https://software.sil.org/lateef/).

- [About](about.md) &mdash; Information about this project and SIL International
- [Resources](resources.md) &mdash; Help with installation and use
- [FAQ](faq.md) &mdash; Common questions and answers
- [Design](design.md) &mdash; History and background of the design
- [Character set support](charset.md) &mdash; Details of Unicode characters that are supported
- [Type Sample](sample.md) &mdash; Type sample demonstrating all the characters in this font
- [Font features](features.md) &mdash; Using smart font features
- [Rendering the Allah ligature](allah.md) &mdash; Special rules for rendering the Allah ligature
- [Support](support.md) &mdash; How to get additional support
- [Developer information](developer.md) &mdash; How to modify and build the fonts
- [Versions](versions.md) &mdash; Sources for alternate versions
- [Version history](history.md) &mdash; Complete version history
- [Announcement](announcement.md) &mdash; Source for News announcement

Additional information is also provided in other project files: [README.txt](../README.txt), [OFL.txt](../OFL.txt), [OFL-FAQ.txt](../OFL-FAQ.txt), and [FONTLOG.txt](../FONTLOG.txt).
